@@ -193,9 +193,9 @@ clearlooks_style_draw_shadow (DRAW_ARGS)
 
 		gtk_style_apply_default_background (style, window, TRUE, state_type,
 		                                    area, x, y, width, height);
-		
-		STYLE_FUNCTION (draw_statusbar) (cr, colors, &params,
-		                                 x, y, width, height);
+		if (shadow_type != GTK_SHADOW_NONE)
+			STYLE_FUNCTION (draw_statusbar) (cr, colors, &params,
+			                                 x, y, width, height);
 	}
 	else if (DETAIL ("frame"))
 	{
@@ -1315,6 +1315,7 @@ clearlooks_style_draw_focus (GtkStyle *style, GdkWindow *window, GtkStateType st
 	focus.has_color = FALSE;
 	focus.interior = FALSE;
 	focus.line_width = 1;
+	focus.padding = 1;
 	dash_list = NULL;
 
 	if (widget)
@@ -1335,9 +1336,21 @@ clearlooks_style_draw_focus (GtkStyle *style, GdkWindow *window, GtkStateType st
 	if (DETAIL("button"))
 	{
 		if (CHECK_HINT (GE_HINT_TREEVIEW_HEADER))
+		{
 			focus.type = CL_FOCUS_TREEVIEW_HEADER;
+		}
 		else
-			focus.type = CL_FOCUS_BUTTON;
+		{
+			GtkReliefStyle relief = GTK_RELIEF_NORMAL;
+			/* Check for the shadow type. */
+			if (widget && GTK_IS_BUTTON (widget))
+				g_object_get (G_OBJECT (widget), "relief", &relief, NULL);
+			
+			if (relief == GTK_RELIEF_NORMAL)
+				focus.type = CL_FOCUS_BUTTON;
+			else
+				focus.type = CL_FOCUS_BUTTON_FLAT;
+		}
 	}
 	else if (detail && g_str_has_prefix (detail, "treeview"))
 	{
@@ -1361,7 +1374,7 @@ clearlooks_style_draw_focus (GtkStyle *style, GdkWindow *window, GtkStateType st
 		}
 		else
 		{
-			/* This may either mean no continuation, or unknown ... 
+			/* This may either mean no continuation, or unknown ...
 			 * if it is unknown we assume it continues on both sides */
 			gboolean row_ending_details = FALSE;
 
@@ -1393,12 +1406,17 @@ clearlooks_style_draw_focus (GtkStyle *style, GdkWindow *window, GtkStateType st
 		else
 			focus.type = CL_FOCUS_COLOR_WHEEL_LIGHT;
 	}
+	else if (DETAIL("checkbutton") || DETAIL("radiobutton"))
+	{
+		focus.type = CL_FOCUS_LABEL; /* Let's call it "LABEL" :) */
+	}
+	else if (CHECK_HINT (GE_HINT_TREEVIEW))
+	{
+		focus.type = CL_FOCUS_TREEVIEW; /* Treeview without content is focused. */
+	}
 	else
 	{
-		if (CHECK_HINT (GE_HINT_TREEVIEW))
-			focus.type = CL_FOCUS_TREEVIEW; /* Let's call it "LABEL" :) */
-		else
-			focus.type = CL_FOCUS_LABEL;
+		focus.type = CL_FOCUS_UNKNOWN; /* Custom widgets (Beagle) and something unknown */
 	}
 	
 	/* Focus color */
